==> gspot_fastapi_auth-0.0.1-py3-none-any.whl: gspot_fastapi_auth/auth.py <==
from typing import Type

from fastapi import Request, HTTPException
from fastapi.security import HTTPBearer, OAuth2PasswordBearer
from starlette.status import HTTP_401_UNAUTHORIZED

from .models import BaseUser, UserFactory
from .providers import RedisClient
from .services import TokenService
from .settings import token_config

oauth2_scheme = OAuth2PasswordBearer(tokenUrl="token")


class UserRedisAuth(HTTPBearer):

    def __init__(self, *args, **kwargs):
        super(UserRedisAuth, self).__init__(*args, **kwargs)
        self._redis_client = RedisClient(
            token_config.host,
            token_config.port,
            token_config.db,
            token_config.password
        )
        self.token_service = TokenService(self._redis_client.session)

    @staticmethod
    def _get_token_from_headers(request: Request) -> str:
        token = request.headers.get('HTTP_AUTHORIZATION')
        if not token:
            raise HTTPException(
                status_code=HTTP_401_UNAUTHORIZED, detail="Not authenticated"
            )
        return token

    @staticmethod
    def _get_token_from_cookies(request: Request) -> str:
        token = request.cookies.get('Authentication')
        if not token:
            raise HTTPException(
                status_code=HTTP_401_UNAUTHORIZED, detail="Not authenticated"
            )
        return token

    async def __call__(self, request: Request) -> Type[BaseUser]:
        if token_config.storage == 'headers':
            token = self._get_token_from_headers(request)
        else:
            token = self._get_token_from_cookies(request)
        data = await self.token_service.get_token_data(token)
        if not data:
            raise HTTPException(
                status_code=HTTP_401_UNAUTHORIZED, detail="Not authenticated"
            )
        user_class = UserFactory().get_user(data.pop('role'))
        return user_class(**data)


__all__ = ['UserRedisAuth', ]

==> gspot_fastapi_auth-0.0.3-py3-none-any.whl: gspot_fastapi_auth/auth.py <==
from typing import Type

from fastapi import HTTPException, Request
from fastapi.security import HTTPBearer, OAuth2PasswordBearer
from starlette.status import HTTP_401_UNAUTHORIZED

from .models import BaseUser, UserFactory
from .providers import RedisClient
from .services import TokenService
from .settings import token_config

oauth2_scheme = OAuth2PasswordBearer(tokenUrl='token')


class UserRedisAuth(HTTPBearer):
    def __init__(self, *args, **kwargs):
        super(UserRedisAuth, self).__init__(*args, **kwargs)
        self._redis_client = RedisClient(
            token_config.host,
            token_config.port,
            token_config.db,
            token_config.password,
        )
        self.token_service = TokenService(self._redis_client.session)

    @staticmethod
    def _get_token_from_headers(request: Request) -> str:
        token = request.headers.get('HTTP_AUTHORIZATION')
        if not token:
            raise HTTPException(status_code=HTTP_401_UNAUTHORIZED, detail='Not authenticated')
        return token

    @staticmethod
    def _get_token_from_cookies(request: Request) -> str:
        token = request.cookies.get('Authentication')
        if not token:
            raise HTTPException(status_code=HTTP_401_UNAUTHORIZED, detail='Not authenticated')
        return token

    async def __call__(self, request: Request) -> Type[BaseUser]:
        if token_config.storage == 'headers':
            token = self._get_token_from_headers(request)
        else:
            token = self._get_token_from_cookies(request)
        data = await self.token_service.get_token_data(token)
        if not data:
            raise HTTPException(status_code=HTTP_401_UNAUTHORIZED, detail='Not authenticated')
        user_class = UserFactory().get_user(data.pop('role'))
        return user_class(**data)


__all__ = [
    'UserRedisAuth',
]
